<?php

/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
namespace Sprinix\Banner\Block;

use Magento\Catalog\Model\Layer\Resolver;
use Magento\Cms\Model\Template\FilterProvider;
use Magento\Framework\App\Request\Http;
use Magento\Framework\UrlInterface;
use Magento\Framework\View\Element\Template;
use Magento\Framework\View\Element\Template\Context;
use Magento\Store\Model\StoreManagerInterface;
use Psr\Log\LoggerInterface;
use Sprinix\Banner\Helper\Data;
use Sprinix\Banner\Model\ResourceModel\Banner\Collection;
use Sprinix\Banner\Model\ResourceModel\Banner\CollectionFactory;

/**
 * Class Banner
 * @package Sprinix\Banner\Block
 */
class Banner extends Template
{
    /**
     * @var Resolver
     */
	protected $layerResolver;

    /**
     * @var StoreManagerInterface
     */
    protected $_storeManager;

    /**
     * @var Http
     */
    protected $request;

    /**
     * @var LoggerInterface
     */
    protected $logger;

    /**
     * @var CollectionFactory
     */
    protected $bannerCollectionFactory;

    /**
     * @var Data
     */
    protected $helper;

    /**
     * Image constructor.
     * @param Context $context
     * @param CollectionFactory $bannerCollectionFactory
     * @param StoreManagerInterface $storemanager
     * @param LoggerInterface $logger
     * @param Resolver $layerResolver
     * @param Http $request
     * @param Data $helper
     * @param array $data
     */
    public function __construct(
        Context $context,
        CollectionFactory $bannerCollectionFactory,
        StoreManagerInterface $storemanager,
        LoggerInterface $logger,
		Resolver $layerResolver,
        FilterProvider $filter,
        Http $request,
        Data $helper,
        array $data = []
    )
    {
        $this->bannerCollectionFactory = $bannerCollectionFactory;
        $this->_storeManager = $storemanager;
        $this->_request = $request;
        $this->helper = $helper;
        $this->filter = $filter;
        $this->layerResolver = $layerResolver;
        $this->logger = $logger;
        parent::__construct($context, $data);
    }

    /**
     * @return Collection
     */
    public function getList()
    {
        try {
            $collection = $this->bannerCollectionFactory->create();
            $collection->addFieldToFilter('status', 1);
            $pageAction = $this->_request->getFullActionName();
            $collection->addFieldToFilter('position', $pageAction);
            $store = $this->_storeManager->getStore()->getId();
            $collection->addFieldToFilter('store_id', array('finset' => $store));
            $category = $this->layerResolver->get()->getCurrentCategory()->getId();
            $page = $this->getRequest()->getParam('p');
            if ($pageAction == 'catalog_category_view') {
             if ($page>1) {
              $collection->addFieldToFilter('page_wise', $page);
              } elseif ($collection->addFieldToFilter('page_wise',1)) {
              $collection->addFieldToFilter('banner_category', array('finset' => $category));
              $collection->setOrder('banner_line', 'DESC');
              }
            }
            foreach ($collection as $data) {
              $template = $data['html_block'];
              $filter = $this->filter->getPageFilter()->filter($template);
                $data['html_block'] = $filter;
            }
            return $collection;
        } catch (\Exception $e) {
            $this->logger->info($e->getMessage());
        }
    }

    /**
     * @return mixed
     */
    public function Enable()
    {
    	return $this->helper->isEnable();
    }

    /**
     * @return mixed
     */
    public function getRow()
    {
        return $this->helper->getRow();
    }

    /**
     * @return mixed
     */
    public function getMediaPath()
    {
        try {
            $mediaUrl = $this->_storeManager->getStore()->getBaseUrl(UrlInterface::URL_TYPE_MEDIA);
            return $mediaUrl;
        } catch (\Exception $e) {
            $this->logger->info($e->getMessage());
        }
    }
}
