<?php
namespace Sprinix\Banner\Controller\Adminhtml\Index;

/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Framework\App\ResponseInterface;
use Magento\Framework\Controller\Result\Redirect;
use Magento\Framework\Controller\ResultInterface;
use Sprinix\Banner\Model\BannerFactory;

/**
 * Class Delete
 * @package Sprinix\Banner\Controller\Adminhtml\Index
 */
class Delete extends Action
{
    /**
     * @var BannerFactory
     */
    protected $bannerFactory;

    /**
     * Delete constructor.
     * @param Context $context
     * @param BannerFactory $bannerFactory
     * @param Banner $resource
     */
    public function __construct(
        Context $context,
        BannerFactory $bannerFactory
    )
    {
        $this->bannerFactory = $bannerFactory;
        parent::__construct($context);
    }

    /**
     * @return ResponseInterface|Redirect|ResultInterface
     */
    public function execute()
    {
        $resultRedirect = $this->resultRedirectFactory->create();
        $id = $this->getRequest()->getParam('banners_id');
        try {
            $bannerModel = $this->bannerFactory->create();
            $bannerModel->load($id);
            $bannerModel->delete();
            $this->messageManager->addSuccessMessage(__('You deleted the row.'));
        } catch (\Exception $e) {
            $this->messageManager->addErrorMessage($e->getMessage());
        }
        return $resultRedirect->setPath('banners/*/index');
    }

    /**
     * @return bool
     */
    public function _isAllowed()
    {
        return $this->_authorization->isAllowed('Sprinix_Banner::delete');
    }
}
