<?php
namespace Sprinix\Banner\Controller\Adminhtml\Index;

/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Framework\App\Request\Http;
use Magento\Framework\App\ResponseInterface;
use Magento\Framework\Controller\ResultInterface;
use Sprinix\Banner\Model\BannerFactory;

/**
 * Class Save
 * @package Sprinix\Banner\Controller\Adminhtml\Index
 */
class Save extends Action
{
    /**
     * @var BannerFactory
     */
    protected $bannerFactory;

    /**
     * @var Http
     */
    protected $request;

    /**
     * Save constructor.
     * @param BannerFactory $bannerFactory
     * @param Http $request
     * @param Context $context
     */
    public function __construct(
        BannerFactory $bannerFactory,
        Http $request,
        Context $context
    ) {
        $this->bannerFactory = $bannerFactory;
        $this->request = $request;
        parent::__construct( $context);
    }

    /**
     * @return ResponseInterface|ResultInterface|void
     */
    public function execute()
    {
        $data = $this->getRequest()->getPostValue();
        try {
            $banner = $this->bannerFactory->create();
            if ($data) {
                if (isset($data['status']) && $data['status'] === 'true') {
                    $data['status'] = Block::STATUS_ENABLED;
                }
                if (isset($data['store_id'])){
                    $data['store_id'] = implode(',', $data['store_id']);
                }
                if (empty($data['banners_id'])) {
                    $data['banners_id'] = null;
                }
                if(isset($data['banner_category'])){
                    $data['banner_category'] = implode(',',$data['banner_category']);
                }
                if (empty($data['banner_category'])) {
                    $data['banner_category'] = null;
                }
                if (isset($data['banners_id'])) {
                    $banner->setEntityId($data['banners_id']);
                }
                if (isset($data['bannerimage'][0]['name'])) {
                    $data['bannerimage'] = $data['bannerimage'][0]['name'];
                } else {
                    $data['bannerimage'] = '';
                }
            }
            $banner->setData($data);
            $banner->save();
            $this->messageManager->addSuccessMessage(__('Data has been successfully saved.'));
        } catch (\Exception $e) {
            $this->messageManager->addErrorMessage(__($e->getMessage()));
        }
        $this->_redirect('banners/index/index');
    }
}
