<?php

namespace Sprinix\Banner\Model;

use Magento\Framework\UrlInterface;
use Magento\Store\Model\StoreManagerInterface;
use Magento\Ui\DataProvider\AbstractDataProvider;
use Psr\Log\LoggerInterface;
use Magento\Cms\Model\Template\FilterProvider;
use Sprinix\Banner\Model\ResourceModel\Banner\CollectionFactory;

/**
 * Class DataProvider
 * @package Sprinix\Banner\Model
 */
class DataProvider extends AbstractDataProvider
{
    /**
     * @var $_loadedData
     */
    protected $_loadedData;

    /**
     * @var LoggerInterface
     */
    protected $logger;
    /**
     * @var StoreManagerInterface
     */
    protected $storeManager;

    /**
     * DataProvider constructor.
     * @param $name
     * @param $primaryFieldName
     * @param $requestFieldName
     * @param CollectionFactory $CollectionFactory
     * @param StoreManagerInterface $storeManager
     * @param LoggerInterface $logger
     * @param array $meta
     * @param array $data
     */
    public function __construct(
        $name,
        $primaryFieldName,
        $requestFieldName,
        CollectionFactory $CollectionFactory,
        StoreManagerInterface $storeManager,
        LoggerInterface $logger,
        FilterProvider $filter,
        array $meta = [],
        array $data = []
    ) {
        $this->collection = $CollectionFactory->create();
        $this->logger = $logger;
        $this->filter = $filter;
        $this->storeManager = $storeManager;
        parent::__construct($name, $primaryFieldName, $requestFieldName , $meta, $data);
    }

    /**
     * @return array
     */
    public function getData()
    {
        try {
            $this->_loadedData = [];
            $items = $this->collection->getItems();
            foreach ($items as $blog) {
                if(isset($blog['banner_category']) && !empty($blog['banner_category'])){
                 $blog['banner_category'] = explode(',',$blog['banner_category']);
                }
                if(isset($blog['store_id']) && !empty($blog['store_id'])){
                    $blog['store_id'] = explode(',',$blog['store_id']);
                }
                $this->_loadedData[$blog->getId()] = $blog->getData();
                if (isset($blog['bannerimage']) && !empty($blog['bannerimage']))
                {
                    $m['bannerimage'][0]['name'] = $blog['bannerimage'];
                    $m['bannerimage'][0]['url'] = $this->getMediaUrl().$blog['bannerimage'];
                    $fullData = $this->_loadedData;
                    $this->_loadedData[$blog->getId()] = array_merge($fullData[$blog->getId()],$m);
                }

            }
            return $this->_loadedData;
        } catch (\Exception $e) {
            $this->logger->info($e->getMessage());
        }
    }

    /**
     * @return string
     */
    public function getMediaUrl()
    {
        try {
            $mediaUrl = $this->storeManager->getStore()->getBaseUrl(UrlInterface::URL_TYPE_MEDIA) . 'banners/image/';
        } catch (\Exception $e) {
            $this->logger->info($e->getMessage());
        }
        return $mediaUrl;
    }
}
